@@ -12,6 +12,11 @@ from inforion.ionapi.model import *
 
 # import inforion.ionapi.basic as inforlogin
 
+import logging
+#from logger import get_logger
+
+import inforion.ionapi.model.inforlogin as inforlogin
+#import inforion.ionapi.basic as inforlogin
 
 class TimeoutHTTPAdapter(HTTPAdapter):
     def __init__(self, *args, **kwargs):
@@ -61,12 +66,11 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
     http.mount("http://", adapter)
 
     if datetime.now() > inforlogin._GLOBAL_session_expire:
-
-        inforlogin.reconnect()
-        print(
-            " Reconnect and Next Reconnect will be "
-            + str(inforlogin._GLOBAL_session_expire)
-        )
+        
+        headers = inforlogin.reconnect()
+        logging.info(" Reconnect and Next Reconnect will be " + str(inforlogin._GLOBAL_session_expire))
+        
+   
 
     try:
         for z in range(0, 5):
@@ -86,25 +90,26 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
                     break
 
                 except ValueError:
+                    logging.error(r)
                     r = "JSON Error"
 
                     print(r)
             else:
 
                 if z < 5:
-                    print(" Error try to get new session " + str(z) + "/5")
-                    inforlogin.reconnect()
-                    time.sleep(10)
+                    logging.info(" Error try to get new session "+ str(z) + "/5")
+                    headers = inforlogin.reconnect()
+                    time.sleep(10)     
                 elif z == 5:
                     sys.exit(0)
 
     except requests.exceptions.TooManyRedirects:
-        print("Too many redirects")
+        logging.error("Too many redirects")
         r = "Error - Too many redirects"
         raise SystemExit(e)
     except requests.exceptions.RequestException as e:
         # catastrophic error. bail.
-        print("OOps: Something Else", e)
+        logging.error("OOps: Something Else",e)
         raise SystemExit(e)
         r = "Error"
 
@@ -161,13 +166,12 @@ def saveresults(r, df, program, index, chunk, MaxChunk=150, elements=1):
                 ] = "Results are missing"
         else:
             for newindex in range(index):
-                # print('Write JSON Error:', str(newindex))
-                df.loc[newindex, "MESSAGE"] = " JSON Error"
+                #logging.info('Write JSON Error:', str(newindex))
+                df.loc[newindex, 'MESSAGE'] = ' JSON Error'
     except:
-        print(r)
-        df.loc[
-            df.index.to_series().between(newindex, index), "MESSAGE"
-        ] = "Unclear Error"
+        logging.error(r)
+        df.loc[df.index.to_series().between(newindex,index), 'MESSAGE'] = 'Unclear Error'
+
 
     chunk = MaxChunk
     data = {"program": program, "cono": 409}
